@@ -6,6 +6,7 @@ SPDX-License-Identifier: Apache-2.0
 import copy
 import logging
 from copy import deepcopy
+from typing import Any
 from typing import Dict
 
 from deepdiff import DeepDiff
@@ -188,4 +189,44 @@ def compare_states(
                     s += f"\\['{part}'\\]"
             exclude_paths.append(s)
 
-    return DeepDiff(plan_state, old_state, exclude_regex_paths=exclude_paths)
+    changes = DeepDiff(old_state, plan_state, exclude_regex_paths=exclude_paths)
+
+    # If an item is in old_state but not in plan_state, i.e. changes.get("dictionary_item_removed") is not None,
+    # we can ignore this change
+
+    # TODO: changes.get("dictionary_item_removed") also includes nested items, which means deleted nested items
+    #  are ignored. Ignore only root items and read-only nested items
+    if (
+        not changes.get("dictionary_item_added")
+        and not changes.get("iterable_item_added")
+        and not changes.get("iterable_item_removed")
+        and not changes.get("values_changed")
+    ):
+        return {}
+
+    return changes
+
+
+def get_project_from_account(ctx: dict, project: str) -> str:
+    """If project is explicitly passed by the user, this project will be returned.
+    If project is empty, this method will return gcp account default project
+    :param ctx: A dict with the keys/values for the execution of the Idem run
+    located in `hub.idem.RUNS[ctx['run_name']]`.
+    :param project: A string explicitly passed by the user.
+    :return: the correct project
+    """
+    if not project:
+        project = ctx.acct.project_id
+    return project
+
+
+# TODO: Enhance this method to work for multi dictionary layers as opposed to now working with only the top one.
+def create_dict_body_on_top_of_old(
+    hub, ctx, old: Dict[str, Any], new: Dict[str, Any]
+) -> Dict[str, Any]:
+    result = copy.deepcopy(old)
+    for key, value in new.items():
+        if value is not None and value != old.get(key):
+            result[key] = value
+
+    return result
